@@ -48,13 +48,13 @@ namespace DirectWriteTypeLayout
             return ComBaseClassHelper<IDWriteTextRenderer>::QueryInterface (refId, result);
         }
 
-        JUCE_COMRESULT IsPixelSnappingDisabled (void* /*clientDrawingContext*/, BOOL* isDisabled) override
+        JUCE_COMRESULT IsPixelSnappingDisabled (void* /*clientDrawingContext*/, BOOL* isDisabled) noexcept override
         {
             *isDisabled = FALSE;
             return S_OK;
         }
 
-        JUCE_COMRESULT GetCurrentTransform (void*, DWRITE_MATRIX* matrix) override
+        JUCE_COMRESULT GetCurrentTransform (void*, DWRITE_MATRIX* matrix) noexcept override
         {
             matrix->m11 = 1.0f; matrix->m12 = 0.0f;
             matrix->m21 = 0.0f; matrix->m22 = 1.0f;
@@ -62,30 +62,30 @@ namespace DirectWriteTypeLayout
             return S_OK;
         }
 
-        JUCE_COMRESULT GetPixelsPerDip (void*, FLOAT* pixelsPerDip) override
+        JUCE_COMRESULT GetPixelsPerDip (void*, FLOAT* pixelsPerDip) noexcept override
         {
             *pixelsPerDip = 1.0f;
             return S_OK;
         }
 
-        JUCE_COMRESULT DrawUnderline (void*, FLOAT, FLOAT, DWRITE_UNDERLINE const*, IUnknown*) override
+        JUCE_COMRESULT DrawUnderline (void*, FLOAT, FLOAT, DWRITE_UNDERLINE const*, IUnknown*) noexcept override
         {
             return E_NOTIMPL;
         }
 
-        JUCE_COMRESULT DrawStrikethrough (void*, FLOAT, FLOAT, DWRITE_STRIKETHROUGH const*, IUnknown*) override
+        JUCE_COMRESULT DrawStrikethrough (void*, FLOAT, FLOAT, DWRITE_STRIKETHROUGH const*, IUnknown*) noexcept override
         {
             return E_NOTIMPL;
         }
 
-        JUCE_COMRESULT DrawInlineObject (void*, FLOAT, FLOAT, IDWriteInlineObject*, BOOL, BOOL, IUnknown*) override
+        JUCE_COMRESULT DrawInlineObject (void*, FLOAT, FLOAT, IDWriteInlineObject*, BOOL, BOOL, IUnknown*) noexcept override
         {
             return E_NOTIMPL;
         }
 
         JUCE_COMRESULT DrawGlyphRun (void* clientDrawingContext, FLOAT baselineOriginX, FLOAT baselineOriginY, DWRITE_MEASURING_MODE,
                                      DWRITE_GLYPH_RUN const* glyphRun, DWRITE_GLYPH_RUN_DESCRIPTION const* runDescription,
-                                     IUnknown* clientDrawingEffect) override
+                                     IUnknown* clientDrawingEffect) noexcept override
         {
             auto layout = static_cast<TextLayout*> (clientDrawingContext);
 
@@ -207,7 +207,7 @@ namespace DirectWriteTypeLayout
         DWRITE_FONT_METRICS dwFontMetrics;
         dwFontFace->GetMetrics (&dwFontMetrics);
 
-        const float totalHeight = (float) (std::abs (dwFontMetrics.ascent) + std::abs (dwFontMetrics.descent));
+        const float totalHeight = (float) (dwFontMetrics.ascent + dwFontMetrics.descent);
         return dwFontMetrics.designUnitsPerEm / totalHeight;
     }
 
